# Models of Brittle-Matrix-Composite Beams

Deflection calculation of a composite beam to predict the serviceability limit state.

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_beam/master?urlpath=%2Fapps%2Fbmcs_beam/bending/deflection_profile.ipynb) - Start a simple example

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_beam/master?urlpath=%2Fapps%2Fwebapps/bmcs_bending_app.ipynb) - Start an interactive webapp

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/bmcs-group/bmcs_beam.git/master?filepath=webapps/bmcs_bending_app.ipynb)
